<template>
  <div class="p-4 container">
    <!-- هدر صفحه -->
    <div class="d-flex justify-content-between align-items-center mb-4">
      <div>
        <h5 class="fw-bold text-dark mb-0">{{ t('business_users.title') }}</h5>
        <p class="text-muted mb-0">{{ data.business.title || t('business_users.no_name') }}</p>
      </div>
      <div>
        <button class="btn btn-default btn-sm ms-2" @click="data.showModal = true">
          <i class="icon icon-regular-plus ms-0 ms-md-1"></i>
          <span class="d-none d-md-inline-block">{{ t('business_users.add_user') }}</span>
        </button>
        <button class="btn btn-outline-secondary btn-sm" @click="goBack">
          <i class="icon icon-regular-arrow-left ms-0 ms-md-1"></i>
          <span class="d-none d-md-inline-block">{{ t('business_users.back') }}</span>
        </button>
      </div>
    </div>

    <!-- کارت لیست کاربران -->
    <div class="card border-0 shadow-sm">
      <div class="card-body p-0">
        <div class="table-responsive">
          <table class="table table-hover mb-0">
            <thead>
            <tr>
              <th class="border-top-0 ps-4">#</th>
              <th class="border-top-0">{{ t('business_users.user_name') }}</th>
              <th class="border-top-0">{{ t('business_users.user_phone') }}</th>
              <th class="border-top-0">{{ t('business_users.user_role') }}</th>
              <th class="border-top-0 text-nowrap">{{ t('business_users.form_advertise') }}</th>
              <th class="border-top-0 text-nowrap">{{ t('business_users.form_special') }}</th>
              <th class="border-top-0 text-nowrap">{{ t('business_users.form_reorder') }}</th>
              <th class="border-top-0 text-nowrap">{{ t('business_users.form_ai') }}</th>
              <th class="border-top-0 text-end pe-4">{{ t('business_users.actions') }}</th>
            </tr>
            </thead>
            <tbody>
            <tr v-for="(user, index) in data.users" :key="index">
              <td class="ps-4">{{ index + 1 }}</td>
              <td>
                <div class="d-flex align-items-center">
                  <div class="ms-2">
                    <img src="/avatar.png" class="rounded-circle" width="40" height="40" alt="User avatar"/>
                  </div>
                  <div>
                    <p class="mb-0 fw-bold">{{ user.name || t('business_users.no_name') }}</p>
                    <small class="text-muted">{{ user.email || t('business_users.no_email') }}</small>
                  </div>
                </div>
              </td>
              <td>{{ user.phone }}</td>
              <td>
                  <span class="badge bg-light text-dark">
                    {{
                      user.role == 'user' ? t('business_users.role_viewer') : t('business_users.role_admin')
                    }}
                  </span>
              </td>
              <td class="text-center">{{ Object.keys(user.attributes).length > 0 ? Object.values(user.attributes).find((item) => item.key == 'advertise').value : '-' }}</td>
              <td class="text-center">{{ Object.keys(user.attributes).length > 0 ? Object.values(user.attributes).find((item) => item.key == 'special').value : '-' }}</td>
              <td class="text-center">{{ Object.keys(user.attributes).length > 0 ? Object.values(user.attributes).find((item) => item.key == 'reorder').value : '-' }}</td>
              <td class="text-center">{{ Object.keys(user.attributes).length > 0 ? Object.values(user.attributes).find((item) => item.key == 'ai').value : '-' }}</td>
              <td class="text-end pe-4">
                <button class="btn btn-sm" @click="removeItem(user.id)">
                  <i class="icon icon-regular-trash text-danger"></i>
                </button>
              </td>
            </tr>
            </tbody>
          </table>
        </div>
      </div>
    </div>

    <!-- مودال افزودن کاربر -->
    <teleport to="body">
      <div
          v-if="data.showModal"
          class="modal fade show d-block"
          tabindex="-1"
          style="background-color: rgba(0, 0, 0, 0.5);"
      >
        <div class="modal-dialog">
          <div class="modal-content">
            <div class="modal-header">
              <h5 class="modal-title">{{ t('business_users.modal_title') }}</h5>
              <button type="button" class="btn-close" @click="data.showModal = false;"></button>
            </div>
            <div class="modal-body">
              <form @submit.prevent="addUser">
                <div class="mb-3">
                  <label class="form-label">{{ t('business_users.form_phone') }}</label>
                  <form-number maxlength="11" v-model="data.form.phone" />
                </div>
                <div class="mb-3">
                  <label class="form-label" for="role">{{ t('business_users.form_role') }}</label>
                  <select v-model="data.form.role" class="form-control" id="role">
                    <option value="admin">مدیر</option>
                    <option value="user">کاربر</option>
                  </select>
                </div>
                <div class="mb-3">
                  <label class="form-label">{{ t('business_users.form_advertise') }}</label>
                  <form-number :disabled="!data.check_package" :placeholder="( !data.check_package ? t('business_users.package') : '')" v-model="data.form.advertise" />
                </div>
                <div class="mb-3">
                  <label class="form-label">{{ t('business_users.form_special') }}</label>
                  <form-number :disabled="!data.check_package" :placeholder="( !data.check_package ? t('business_users.package') : '')" v-model="data.form.special" />
                </div>
                <div class="mb-3">
                  <label class="form-label">{{ t('business_users.form_reorder') }}</label>
                  <form-number :disabled="!data.check_package" :placeholder="( !data.check_package ? t('business_users.package') : '')" v-model="data.form.reorder" />
                </div>
                <div class="mb-3">
                  <label class="form-label">{{ t('business_users.form_ai') }}</label>
                  <form-number :disabled="!data.check_package" :placeholder="( !data.check_package ? t('business_users.package') : '')" v-model="data.form.ai" />
                </div>
                <div class="d-grid gap-2">
                  <button type="submit" class="btn btn-default">{{ t('business_users.form_submit') }}</button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </teleport>
  </div>
</template>

<script setup>
import {ref, onMounted} from 'vue'
import {useRoute, useRouter} from 'vue-router'
import {useI18n} from 'vue-i18n'
import Swal from 'sweetalert2'
import {useCookie} from "nuxt/app";

const {$api,$sweetalert} = useNuxtApp()
const {t} = useI18n()
const token = useCookie('token')
const router = useRouter()
const route = useRoute()
const id = ref(route.params.id)

const data = reactive({
  form: {
    phone: "",
    role: "",
    advertise: "",
    special: "",
    reorder: "",
    ai: "",
  },
  check_package: false,
  users: [],
  business: {},
  showModal: false,
});

definePageMeta({
  layout: 'default',
  middleware: ['auth']
});


const goBack = () => router.back()

const getUsers = async () => {
  await $api.post('/user/business/user', {
    business_id: id.value
  }).then((value) => {
    if (value.data.status) {
      data.users = value.data.data;
      console.log(data.users[0].attributes)
    }
  })
}

const getBusiness = async () => {
  await $api.post('/user/business/show', {
    id: id.value
  }).then((value) => {
    if (value.data.status) {
      if(value.data.data.role == 'user') {
        router.push('/account/business')
      }
      data.business = value.data.data;

      if(Object.keys(data.business.package).length > 0) {
        data.check_package = true;
      }
    }
  })
}

const addUser = async () => {
  await $api.post('/user/business/user/create', {
    business_id: id.value,
    phone: data.form.phone,
    role: data.form.role,
    advertise: data.form.advertise,
    special: data.form.special,
    reorder: data.form.reorder,
    ai: data.form.ai,
  }).then((value) => {
    if (value.data.status) {
      data.showModal = false;
      data.form = {
        phone: "",
        role: "",
        advertise: data.check_package ? "0" : "",
        special: data.check_package ? "0" : "",
        reorder: data.check_package ? "0" : "",
        ai: data.check_package ? "0" : "",
      };
      $sweetalert.success(t('business_users.add_success'));
      getUsers()
    } else {
      $sweetalert.error(t('business_users.add_error'));
    }
  })
}

const removeItem = async (userId) => {
  await $sweetalert.confirm(async () => {
    await $api.post('/user/business/user/delete', {
      business_id: id.value,
      user_id: userId
    }, {
      headers: {
        Authorization: `Bearer ${useCookie('token').value}`
      }
    }).then((value) => {
      if (value.data.status) {
        $sweetalert.success(t('business_users.delete_confirm_success'));
        getUsers();
      } else {
        $sweetalert.error(t('business_users.delete_confirm_error'));
      }
    })
  });
};


onMounted(() => {
  getUsers()
  getBusiness()
});
</script>

<style scoped>
.table th {
  font-weight: 600;
  color: #6c757d;
  background-color: #f8f9fa;
}

.table td, .table th {
  vertical-align: middle;
  padding: 1rem;
}

.user-avatar {
  width: 40px;
  height: 40px;
  object-fit: cover;
}

</style>
